@@ -514,22 +514,20 @@ class GradientColorStop(xmlc.PyScribusElement):
 
                 if setting_name == "position":
                     self.position = dimensions.Dim(
-                        float(setting_value), "pcdecim"
+                        float(setting_value), unit="pcdecim"
                     )
 
                 if setting_name == "opacity":
                     self.opacity = dimensions.Dim(
-                        float(setting_value), "pcdecim"
+                        float(setting_value), unit="pcdecim"
                     )
 
                 if setting_name == "shade":
-                    self.shade = dimensions.Dim(
-                        float(setting_value), "pc"
-                    )
+                    self.shade = dimensions.Dim(float(setting_value), unit="pc")
 
-    def fromdefault(self):
-        self.opacity = dimensions.Dim(100, "pc")
-        self.position = dimensions.Dim(0, "pcdecim")
+    def fromdefault(self) -> NoReturn:
+        self.opacity = dimensions.Dim(100, unit="pc")
+        self.position = dimensions.Dim(0, unit="pcdecim")
 
     def fromxml(self, xml):
         if xml.tag == "CSTOP":
@@ -540,15 +538,16 @@ class GradientColorStop(xmlc.PyScribusElement):
 
             shade = xml.get("SHADE")
             if shade is not None:
-                self.shade = dimensions.Dim(float(shade), "pc")
+                self.shade = dimensions.Dim(float(shade), unit="pc")
 
             ramp = xml.get("RAMP")
             if ramp is not None:
-                self.position = dimensions.Dim(float(ramp), "pcdecim")
+                self.position = dimensions.Dim(float(ramp), unit="pcdecim")
 
             opacity = xml.get("TRANS")
             if opacity is not None:
                 self.opacity = dimensions.Dim(float(opacity), "pcdecim")
+                self.opacity = dimensions.Dim(float(opacity), unit="pcdecim")
 
             return True
 
