@@ -24,7 +24,9 @@ PyScribus classes for measures and geometrical manipulations.
 import copy
 import math
 
-from pyscribus.common.math import PICA_TO_MM,INCH_TO_MM
+from typing import Union, Literal
+
+from pyscribus.common.math import PICA_TO_MM
 
 import pyscribus.logs as logs
 import pyscribus.exceptions as exceptions
@@ -38,45 +40,71 @@ from pyscribus.common.xml import *
 
 __author__ = "Etienne Nadji <etnadji@eml.cc>"
 
+XY = Literal["x", "y"]
+DimValue = Union[float, int]
+BoxCorner = Literal["top-left", "top-right", "bottom-left", "bottom-right"]
+
 # Classes ===============================================================#
 
 class Dim:
     """
     Dimension object. Allows to convert and export in the correct unit.
 
-    :type value: float,int
+    :type value: Union[float, int]
     :param value: Value of the dimension
+
     :type unit: str
     :param unit: Unit of the dimension.
     :type is_int: boolean
     :param is_int: Use integer instead of float type for value
 
+    :type kwargs: dict
+    :param kwargs: Dimension settings (see kwargs table)
+
     :ivar float,int value: Value of the dimension in the original unit
     :ivar string unit: Unit of the dimension
 
-    +-------------------------+---------------+
-    | Unit / Notation         | unit argument |
-    +=========================+===============+
-    | Milimeter               | mm            |
-    +-------------------------+---------------+
-    | Pica point              | pica, pct     |
-    +-------------------------+---------------+
-    | Typographic point       | pt            |
-    +-------------------------+---------------+
-    | Percentage (0 to 100)   | perc, pc      |
-    +-------------------------+---------------+
-    | Percentage (0.0 to 1)   | pcdecim, pcd  |
-    +-------------------------+---------------+
-    | Calligraphic pen degree | cdeg          |
-    +-------------------------+---------------+
-    | Regular degree          | deg           |
-    +-------------------------+---------------+
-    | Dot per inch (DPI/PPP)  | dpi, ppp, ppi |
-    +-------------------------+---------------+
-    | Line per inch (LPI)     | lpi           |
-    +-------------------------+---------------+
-    | Second                  | s, sec        |
-    +-------------------------+---------------+
+    +---------------+------------------------------------+
+    | Kwargs        | Setting                            |
+    +===============+====================================+
+    | unit          | Unit of the dimension. See unit    |
+    |               | table.                             |
+    +---------------+------------------------------------+
+    | integer       | The value of the dimension is an   |
+    |               | integer instead of a float.        |
+    +---------------+------------------------------------+
+    | negative      | Allow the dimension to have        |
+    |               | negative value.                    |
+    +---------------+------------------------------------+
+    | original_unit |                                    |
+    +---------------+------------------------------------+
+
+    +--------------------------+---------------+
+    | Unit / Notation          | unit argument |
+    +==========================+===============+
+    | Milimeter                | mm            |
+    +--------------------------+---------------+
+    | Pica point               | pica, pct     |
+    +--------------------------+---------------+
+    | Typographic point        | pt            |
+    +--------------------------+---------------+
+    | Percentage (0 to 100)    | perc, pc      |
+    +--------------------------+---------------+
+    | Percentage (0.0 to 1)    | pcdecim, pcd  |
+    +--------------------------+---------------+
+    | Percentage (decimal, can | pcscale       |
+    | be more than 1.0)        |               |
+    +--------------------------+---------------+
+    | Calligraphic pen degree  | cdeg          |
+    +--------------------------+---------------+
+    | Regular degree           | deg           |
+    +--------------------------+---------------+
+    | Dot per inch (DPI/PPP)   | dpi, ppp, ppi |
+    +--------------------------+---------------+
+    | Line per inch (LPI)      | lpi           |
+    +--------------------------+---------------+
+    | Second                   | s, sec        |
+    +--------------------------+---------------+
     """
 
     # 1 pica point = 25,4/72 milimeters
@@ -95,19 +123,30 @@ class Dim:
         "sec": ["s", "sec"]
     }
 
-    def __init__(self, value, unit="pica", is_int=False, original_unit=False):
-        self.is_int = False
-
-        if is_int:
-            self.is_int = True
-            value = int(value)
-
+    def __init__(self, value: DimValue, **kwargs: dict):
         self.value = value
+        self.integer = False
+        self.allow_negative = False
 
-        self.set_unit(unit)
+        if "integer" in kwargs:
+            self.integer = bool(kwargs["integer"])
 
-        if original_unit:
-            self.from_original_unit(original_unit)
+        if "negative" in kwargs:
+            self.allow_negative = bool(kwargs["negative"])
+
+        if self.integer:
+            self.value = int(self.value)
+
+        if "unit" in kwargs:
+            self.set_unit(kwargs["unit"])
+        else:
+            self.set_unit("pica")
+
+        if "original_unit" in kwargs:
+            if kwargs["original_unit"]:
+                self.from_original_unit(kwargs["original_unit"])
+
+        print(self.__repr__())
 
         self.check_value()
 
@@ -128,9 +167,12 @@ class Dim:
         if self.unit in ["pica", "pct"]:
 
             if self.value < 0:
-                raise exceptions.InvalidDim(
-                    "Pica points must not be inferior to 0."
-                )
+                if not self.allow_negative:
+                    raise exceptions.InvalidDim(
+                        "Pica points must not be inferior to 0 in that context. From {}".format(
+                            self.__repr__()
+                        )
+                    )
 
         if self.unit == "dpi":
 
@@ -230,7 +272,7 @@ class Dim:
                 break
 
         if self.unit == "sec":
-            self.is_int = True
+            self.integer = True
             self.value = int(self.value)
 
         return valid_unit
@@ -254,7 +296,18 @@ class Dim:
             else:
                 return n
 
-        if self.unit not in ["perc", "pcdecim", "cdeg", "deg", "lpi", "dpi"]:
+            return number
+
+        if self.unit not in [
+            "perc",
+            "pcdecim",
+            "pcscale",
+            "cdeg",
+            "deg",
+            "lpi",
+            "dpi",
+            "pt",
+        ]:
             if no_useless_decimals:
                 pica = self.topica()
                 return str(decimals(pica))
@@ -315,9 +368,9 @@ class Dim:
         """
 
         if obj:
-            return Dim(value, unit)
-        else:
-            return value
+            return Dim(value, unit=unit)
+
+        return value
 
     def is_convertable_length(self):
         """
@@ -325,12 +378,14 @@ class Dim:
         :return: If the Dim instance is a convertable length
         """
 
-        if self.unit in ["perc", "pcdecim", "cdeg", "deg", "dpi", "lpi"]:
-            return False
+        return not (
+            self.unit
+            in ["perc", "pcdecim", "pcscale", "cdeg", "deg", "dpi", "lpi"]
+        )
 
-        return True
-
-    def topica(self, ceil=False, obj=False):
+    def topica(
+        self, ceil: bool = False, obj: bool = False
+    ) -> Union[float, int, Dim]:
         """
         Returns the value of Dim in pica point unit.
         Raise ValueError if Dim is not convertable
@@ -356,7 +411,9 @@ class Dim:
                 obj, self._ceil(self.value / Dim.PICA_TO_MM, ceil), "pica"
             )
 
-    def todpi(self, ceil=False, obj=False):
+    def todpi(
+        self, ceil: bool = False, obj: bool = False
+    ) -> Union[float, int, Dim]:
         """
         Returns the value of Dim in DPI unit.
         Raise ValueError if Dim is not convertable
@@ -396,7 +453,9 @@ class Dim:
                 "Can't convert that into percentage"
             )
 
-    def tolpi(self, ceil=False, obj=False):
+    def tolpi(
+        self, ceil: bool = False, obj: bool = False
+    ) -> Union[float, int, Dim]:
         """
         Returns the value of Dim in LPI unit.
         Raise ValueError if Dim is not convertable
@@ -416,7 +475,9 @@ class Dim:
                 "Can't convert that into LPI"
             )
 
-    def tomm(self, ceil=False, obj=False):
+    def tomm(
+        self, ceil: bool = False, obj: bool = False
+    ) -> Union[float, int, Dim]:
         """
         Returns the value of Dim in milimeter unit.
 
@@ -496,8 +557,8 @@ class Dim:
         return "{} {}".format(r, u)
 
     def __repr__(self):
-        return "Dim(value={}, unit={}, is_int={})".format(
-            self.value, self.unit, self.is_int
+        return "Dim(value={}, unit={}, integer={}, negative={})".format(
+            self.value, self.unit, self.integer, self.allow_negative
         )
 
     def __float__(self):
@@ -605,7 +666,7 @@ class DimBox:
         # Coords & angle for rotated boxes --------------------------
         # NOTE rotated_coords is modified through set_box and rotate
 
-        self.rotation = Dim(0, "deg")
+        self.rotation = Dim(0, unit="deg")
         self.rotated_coords = {
             "top-left": [Dim(0), Dim(0)],
             "top-right": [Dim(0), Dim(0)],
@@ -619,7 +680,9 @@ class DimBox:
 
     #--- Shorthands for corners coordinates ------------------------------
 
-    def _setxy(self, corner, value, xy, rotated=False):
+    def _setxy(
+        self, corner: BoxCorner, value, xy: XY, rotated: bool = False
+    ) -> bool:
         if corner.lower() in [
                 "top-left", "top-right",
                 "bottom-left", "bottom-right"]:
@@ -639,7 +702,9 @@ class DimBox:
         else:
             raise KeyError()
 
-    def _getxy(self, corner, xy, rotated=False):
+    def _getxy(
+        self, corner: BoxCorner, xy: XY, rotated: bool = False
+    ) -> Union[float, int]:
         if corner.lower() in [
                 "top-left", "top-right",
                 "bottom-left", "bottom-right"]:
@@ -662,15 +727,24 @@ class DimBox:
     def sety(self, corner, value, rotated=False):
         return self._setxy(corner, value, "y", rotated)
 
-    def getx(self, corner, rotated=False):
+    def getx(
+        self, corner: BoxCorner, rotated: bool = False
+    ) -> Union[float, int]:
         return self._getxy(corner, "x", rotated)
 
-    def gety(self, corner, rotated=False):
+    def gety(
+        self, corner: BoxCorner, rotated: bool = False
+    ) -> Union[float, int]:
         return self._getxy(corner, "y", rotated)
 
     #--- Box modification ------------------------------------------------
 
-    def move(self, posx=0, posy=0, refpoint="top-left"):
+    def move(
+        self,
+        posx: float = 0,
+        posy: float = 0,
+        refpoint: BoxCorner = "top-left",
+    ) -> bool:
         """
         Move the box at posx, posy position.
 
