@@ -188,14 +188,14 @@ class Document(PyScribusElement):
         # ----------------------------------------------
 
         self.calligraphicpen = {
-            "angle": dimensions.Dim(0, "cdeg", True),
-            "line_width": dimensions.Dim(0, "pica"),
-            "line_shade": dimensions.Dim(100, "perc", True),
+            "angle": dimensions.Dim(0, unit="cdeg", integer=True),
+            "line_width": dimensions.Dim(0, unit="pica"),
+            "line_shade": dimensions.Dim(100, unit="perc", integer=True),
             "line_color": "",
-            "width": dimensions.Dim(0, "pica"),
+            "width": dimensions.Dim(0, unit="pica"),
             "style": "1",
             "fill_color": "",
-            "fill_shade": dimensions.Dim(100, "perc", True),
+            "fill_shade": dimensions.Dim(100, unit="perc", is_int=True),
         }
 
         # ----------------------------------------------
@@ -206,7 +206,7 @@ class Document(PyScribusElement):
             "columns": 1,
             # Distance between Columns in automatic Textframes
             # ABSTSPALTEN = "11"
-            "colgap": dimensions.Dim(11, "pt")
+            "colgap": dimensions.Dim(11, unit="pt")
         }
 
         # ----------------------------------------------
@@ -521,14 +521,14 @@ class Document(PyScribusElement):
         """
 
         self.calligraphicpen = {
-            "angle": dimensions.Dim(0, "cdeg", True),
-            "line_width": dimensions.Dim(0, "pica"),
-            "line_shade": dimensions.Dim(100, "perc", True),
+            "angle": dimensions.Dim(0, unit="cdeg", integer=True),
+            "line_width": dimensions.Dim(0, unit="pica"),
+            "line_shade": dimensions.Dim(100, unit="perc", integer=True),
             "line_color": "",
-            "width": dimensions.Dim(0, "pica"),
+            "width": dimensions.Dim(0, unit="pica"),
             "style": 1,
             "fill_color": "",
-            "fill_shade": dimensions.Dim(100, "perc", True),
+            "fill_shade": dimensions.Dim(100, unit="perc", integer=True),
         }
 
     def _default_pagesets(self):
@@ -1010,7 +1010,7 @@ class Document(PyScribusElement):
 
         # Pages settings
 
-        xml.attrib["ORIENTATION"] = int(self.doc_pages["orientation"])
+        xml.attrib["ORIENTATION"] = str(int(self.doc_pages["orientation"]))
 
         for att, human in pages.xml_size.items():
             if human == self.doc_pages["size"]:
@@ -1022,8 +1022,10 @@ class Document(PyScribusElement):
         # Auto text frames
 
         for att, human in Document.autoframes_xml.items():
+
             if human == "columns":
                 xml.attrib[att] = str(self.autoframes[human])
+
             if human == "colgap":
                 xml.attrib[att] = self.autoframes[human].toxmlstr(True)
 
@@ -1631,8 +1633,8 @@ class Profile(PyScribusElement):
         self.ignores = {"Errors": False, "OffLayers": False}
 
         self.resolution = {
-            "min": dimensions.Dim(0, "dpi", True),
-            "max": dimensions.Dim(0, "dpi", True)
+            "min": dimensions.Dim(0, unit="dpi", integer=True),
+            "max": dimensions.Dim(0, unit="dpi", integer=True),
         }
 
         if default:
@@ -1850,137 +1852,4 @@ class Profile(PyScribusElement):
         else:
             return False
 
-
-class Layer(PyScribusElement):
-    """
-    Layer in SLA (LAYERS)
-
-    :type default: bool
-    :param default: Set default attributes for layer
-    """
-
-    blendmodes_to_xml = {
-        "normal": "0", "darken": "1", "lighten": "2", "multiply": "3", "screen": "4",
-        "overlay": "5", "hard-light": "6", "soft-light": "7", "substract": "8",
-        "exclusion": "9", "color-dodge": "10", "color-burn": "11", "hue": "12",
-        "saturation": "13", "color": "14", "luminosity": "15",
-    }
-
-    def __init__(self, default=False):
-        super().__init__()
-
-        if default:
-            self.fromdefault()
-        else:
-            self.name = ""
-            self.level = 0
-            self.number = 0
-            self.opacity = dimensions.Dim(1, "pcdecim")
-            self.visible = True
-            self.editable = True
-            self.printable = True
-            self.color = "#000000"
-            self.wireframe = False
-            self.blend = "normal"
-            self.flow = False
-            self.selectable = False
-
-    def fromdefault(self):
-        self.name = "Fond de page"
-        self.level = 0
-        self.number = 0
-        self.visible = True
-        self.editable = True
-        self.printable = True
-        self.color = "#000000"
-        self.wireframe = False
-        self.opacity = dimensions.Dim(1, "pcdecim")
-        self.blend = "normal"
-        self.flow = True
-        self.selectable = False
-
-    def fromxml(self, xml):
-        number = xml.get("NUMMER")
-
-        if number is not None:
-            self.number = int(number)
-
-            name = xml.get("NAME")
-            edit = xml.get("EDIT")
-            level = xml.get("LEVEL")
-            color = xml.get("LAYERC")
-            visible = xml.get("SICHTBAR")
-            printable = xml.get("DRUCKEN")
-            opacity = xml.get("TRANS")
-            wireframe = xml.get("OUTL")
-            # Blend mode of layer
-            blend = xml.get("BLEND")
-            # Habillage des cadres actif
-            flow = xml.get("FLOW")
-            # Objets du calque selectionnables même si le calque est non sélectionné
-            selectable = xml.get("SELECT")
-
-            if color is not None:
-                self.color = color
-
-            if name is not None:
-                self.name = name
-
-            if level is not None:
-                self.level = int(level)
-
-            if edit is not None:
-                self.editable = num_to_bool(edit)
-
-            if visible is not None:
-                self.visible = num_to_bool(visible)
-
-            if printable is not None:
-                self.printable = num_to_bool(printable)
-
-            if opacity is not None:
-                self.opacity.value = float(opacity)
-
-            if wireframe is not None:
-                self.wireframe = num_to_bool(wireframe)
-
-            if flow is not None:
-                self.flow = num_to_bool(flow)
-
-            if selectable is not None:
-                self.selectable = num_to_bool(selectable)
-
-            if blend is not None:
-
-                for code,human in Layer.blendmodes_to_xml.items():
-
-                    if code == blend:
-                        self.blend = human
-                        break
-
-            return True
-
-        else:
-            return False
-
-    def toxml(self):
-        xml = ET.Element("LAYERS")
-
-        xml.attrib["NUMMER"] = str(self.number)
-        xml.attrib["LEVEL"] = str(self.level)
-        xml.attrib["NAME"] = self.name
-
-        for case in [
-            ["SICHTBAR", self.visible], ["DRUCKEN", self.printable],
-            ["EDIT", self.editable], ["SELECT", self.selectable],
-            ["FLOW", self.flow]]:
-            xml.attrib[case[0]] = bool_to_num(case[1])
-
-        xml.attrib["TRANS"] = self.opacity.toxmlstr()
-        xml.attrib["BLEND"] = Layer.blendmodes_to_xml[self.blend]
-        xml.attrib["OUTL"] = bool_to_num(self.wireframe)
-        xml.attrib["LAYERC"] = self.color
-
-        return xml
-
 # vim:set shiftwidth=4 softtabstop=4 spl=en:
