@@ -40,11 +40,11 @@ import lxml
 import lxml.etree as ET
 
 import pyscribus.logs as logs
+import pyscribus.common.xml as xmlc
+import pyscribus.common.math as mathc
 import pyscribus.exceptions as exceptions
 import pyscribus.dimensions as dimensions
 
-from pyscribus.common.xml import *
-
 # Variables globales ====================================================#
 
 __author__ = "Etienne Nadji <etnadji@eml.cc>"
@@ -74,7 +74,7 @@ class Orientation(IntEnum):
     LANDSCAPE = 1
 
 
-class PageAbstract(PyScribusElement):
+class PageAbstract(xmlc.PyScribusElement):
     """
     Abstract class for pages and master pages.
 
@@ -87,7 +87,7 @@ class PageAbstract(PyScribusElement):
     """
 
     orientation_xml = {"portrait": "0", "landscape": "1"}
-    autoguides_origin_xml = {"page": "0", "margins": "1"}
+    autoguides_origin_xml = {"page": "0", "margins": "1", "selection": "2"}
 
     effect_source_xml = {"internal": "0", "external": "1"}
     effect_mobile_line_xml = {"horizontal": "0", "vertical": 1}
@@ -113,7 +113,7 @@ class PageAbstract(PyScribusElement):
     }
 
     def __init__(self, **kwargs):
-        PyScribusElement.__init__(self)
+        xmlc.PyScribusElement.__init__(self)
 
         self.box = dimensions.DimBox()
 
@@ -140,39 +140,52 @@ class PageAbstract(PyScribusElement):
             "vertical": []
         }
 
-        #--- FIXME Not documented ----------------------------------------
+        # ----------------------------------------------------------------
 
-        # For multipage spreads, which page in the spread is the left most
-        # LEFT="0"
+        # @LEFT - For multipage spreads, which page in the spread is the left most
+        self.is_leftest = False
+
+        # FIXME Not documented -------------------------------------------
 
         # PRESET="0"
 
         #--- Auto guides -------------------------------------------------
 
-        # FIXME Understand AGSelection usage
-        # AGSelection="0 0 0 0"
-
         self.auto_guides = {
             "lines": {
+                # @AGhorizontalAutoCount
                 "count": 0,
+                # @AGhorizontalAutoGap
                 "gap": dimensions.Dim(0),
+                # @AGhorizontalAutoRefer
                 "origin": "page"
             },
             "columns": {
+                # @AGverticalAutoCount
                 "count": 0,
+                # @AGverticalAutoGap
                 "gap": dimensions.Dim(0),
-                "origin": "page"
+                # @AGverticalAutoRefer
+                "origin": "page",
             },
-            "selection": []
+            # @AGSelection
+            # In XML, this is a string of floats X, Y, Width, Height separated
+            # by spaces.
+            "selection": {
+                "posx": dimensions.Dim(0),
+                "posy": dimensions.Dim(0),
+                "width": dimensions.Dim(0),
+                "height": dimensions.Dim(0),
+            }
         }
 
         #--- PDF effects -------------------------------------------------
 
         self.effect = {
             # @pageEffectDuration
-            "duration": dimensions.Dim(1, "sec"),
+            "duration": dimensions.Dim(1, unit="sec"),
             # @pageViewDuration
-            "view-duration": dimensions.Dim(1, "sec"),
+            "view-duration": dimensions.Dim(1, unit="sec"),
             # @effectType
             "type": "none",
             # @Dm
@@ -202,7 +215,7 @@ class PageAbstract(PyScribusElement):
         """
 
         if settings:
-            PyScribusElement._quick_setup(self, settings)
+            xmlc.PyScribusElement._quick_setup(self, settings)
 
             for setting_name, setting_value in settings.items():
 
@@ -318,160 +331,163 @@ class PageAbstract(PyScribusElement):
         else:
             tag = "PAGE"
 
-        if xml.tag == tag:
-            #--- Box settings -------------------------------------
+        if xml.tag != tag:
+            return False
 
-            posx = xml.get("PAGEXPOS")
-            posy = xml.get("PAGEYPOS")
-            dim_width = xml.get("PAGEWIDTH")
-            dim_height = xml.get("PAGEHEIGHT")
+        #--- Box settings -------------------------------------
 
-            valid_box = 0
+        posx = xml.get("PAGEXPOS")
+        posy = xml.get("PAGEYPOS")
+        dim_width = xml.get("PAGEWIDTH")
+        dim_height = xml.get("PAGEHEIGHT")
 
-            for test in [posx, posy, dim_width, dim_height]:
-                if test is not None:
-                    valid_box += 1
+        valid_box = 0
 
-            if valid_box == 4:
+        for test in [posx, posy, dim_width, dim_height]:
+            if test is not None:
+                valid_box += 1
 
-                self.box.set_box(
-                    top_lx=posx, top_ly=posy,
-                    width=dim_width, height=dim_height
-                )
+        if valid_box == 4:
 
-            #--- Name / Master page name --------------------------
+            self.box.set_box(
+                top_lx=posx, top_ly=posy,
+                width=dim_width, height=dim_height
+            )
 
-            self.name = xml.get("NAM")
-            self.master_name = xml.get("MNAM")
+        #--- Name / Master page name --------------------------
 
-            #--- Page number --------------------------------------
+        self.name = xml.get("NAM")
+        self.master_name = xml.get("MNAM")
 
-            page_number = xml.get("NUM")
+        is_leftest = xml.get("LEFT")
+        if is_leftest is not None:
+            self.is_leftest = xmlc.num_to_bool(is_leftest)
 
-            if page_number is not None:
-                # NOTE Page 0 is the first page so we adjust to a human
-                # readable count
-                self.number = int(page_number) + 1
+        page_number = xml.get("NUM")
 
-            #--- Paper size name and orientation ------------------
+        if page_number is not None:
+            # NOTE Page 0 is the first page so we adjust to a human
+            # readable count
+            self.number = int(page_number) + 1
 
-            paper_size = xml.get("Size")
-            if paper_size is not None:
-                self.paper_size = paper_size
+        #--- Paper size name and orientation ------------------
 
-            orientation = xml.get("Orientation")
-            if orientation is not None:
+        paper_size = xml.get("Size")
+        if paper_size is not None:
+            self.paper_size = paper_size
 
-                for h,x in PageAbstract.orientation_xml.items():
-                    if orientation == x:
-                        self.orientation = h
-                        break
+        orientation = xml.get("Orientation")
+        if orientation is not None:
 
-            #--- Borders ------------------------------------------
+            for h,x in PageAbstract.orientation_xml.items():
+                if orientation == x:
+                    self.orientation = h
+                    break
 
-            for b in ["left", "top", "bottom", "right"]:
-                att = "BORDER{}".format(b.upper())
-                self.borders[b] = dimensions.Dim(float(xml.get(att)))
+        #--- Borders ------------------------------------------
 
-            #--- Guides -------------------------------------------
+        for b in ["left", "top", "bottom", "right"]:
+            att = "BORDER{}".format(b.upper())
+            self.borders[b] = dimensions.Dim(float(xml.get(att)))
 
-            for guide_type in ["vertical", "horizontal"]:
+        #--- Guides -------------------------------------------
 
-                att_name = "{}Guides".format(guide_type.capitalize())
+        for guide_type in ["vertical", "horizontal"]:
 
-                att = xml.get(att_name)
-                if att is not None:
-                    if att:
-                        # NOTE Example of att value : "42.5197 56.6929 "
+            att_name = "{}Guides".format(guide_type.capitalize())
 
-                        guides_list = []
-                        guides_values = [g.strip() for g in att.split(" ")]
+            att = xml.get(att_name)
+            if att is not None:
+                if att:
+                    # NOTE Example of att value : "42.5197 56.6929 "
 
-                        for g in guides_values:
+                    guides_list = []
+                    guides_values = [g.strip() for g in att.split(" ")]
 
-                            if g:
+                    for g in guides_values:
 
-                                guides_list.append(
-                                    dimensions.Dim(float(g))
-                                )
+                        if g:
 
-                        # self.guides[guide_type] = att
-                        self.guides[guide_type] = guides_list
+                            guides_list.append(
+                                dimensions.Dim(float(g))
+                            )
 
-            #--- Auto guides --------------------------------------
+                    # self.guides[guide_type] = att
+                    self.guides[guide_type] = guides_list
 
-            for case in [["lines", "horizontal"], ["columns", "vertical"]]:
-                ag_count = xml.get("AG{}AutoCount".format(case[1]))
-                ag_gap = xml.get("AG{}AutoGap".format(case[1]))
-                ag_origin = xml.get("AG{}AutoRefer".format(case[1]))
+        #--- Auto guides --------------------------------------
 
-                if ag_count is not None:
-                    ag_count = int(ag_count)
-                    self.auto_guides[case[0]]["count"] = ag_count
+        for case in [["lines", "horizontal"], ["columns", "vertical"]]:
+            ag_count = xml.get("AG{}AutoCount".format(case[1]))
+            ag_gap = xml.get("AG{}AutoGap".format(case[1]))
+            ag_origin = xml.get("AG{}AutoRefer".format(case[1]))
 
-                if ag_gap is not None:
-                    ag_gap = float(ag_gap)
-                    self.auto_guides[case[0]]["gap"].value = ag_gap
+            if ag_count is not None:
+                ag_count = int(ag_count)
+                self.auto_guides[case[0]]["count"] = ag_count
 
-                if ag_origin is not None:
+            if ag_gap is not None:
+                ag_gap = float(ag_gap)
+                self.auto_guides[case[0]]["gap"].value = ag_gap
 
-                    for human,code in PageAbstract.autoguides_origin_xml.items():
-                        if ag_origin == code:
-                            self.auto_guides[case[0]]["origin"] = human
+            if ag_origin is not None:
 
-            #--- PDF effects -------------------------------------------------
+                for human,code in PageAbstract.autoguides_origin_xml.items():
+                    if ag_origin == code:
+                        self.auto_guides[case[0]]["origin"] = human
 
-            duration = xml.get("pageEffectDuration")
-            if duration is not None:
-                self.effect["duration"].value = int(duration)
+        ag_selection = xml.get("AGSelection")
+        if ag_selection is not None:
+            agx, agy, agw, agh = [float(dim) for dim in ag_selection.split()]
 
-            view_duration = xml.get("pageViewDuration")
-            if view_duration is not None:
-                self.effect["view-duration"].value = int(view_duration)
+            self.auto_guides["selection"]["posx"].value = agx
+            self.auto_guides["selection"]["posy"].value = agy
+            self.auto_guides["selection"]["width"].value = agw
+            self.auto_guides["selection"]["height"].value = agh
 
-            effect_type = xml.get("effectType")
-            if effect_type is not None:
-                for human, code in PageAbstract.effect_type_xml.items():
-                    if effect_type == code:
-                        self.effect["type"] = human
-                        break
+        #--- PDF effects -------------------------------------------------
 
-            effect_lines = xml.get("Dm")
-            if effect_lines is not None:
-                for human, code in PageAbstract.effect_mobile_line_xml.items():
-                    if effect_lines == code:
-                        self.effect["mobile-lines"] = human
-                        break
+        duration = xml.get("pageEffectDuration")
+        if duration is not None:
+            self.effect["duration"].value = int(duration)
 
-            effect_source = xml.get("M")
-            if effect_source is not None:
-                for human, code in PageAbstract.effect_source_xml.items():
-                    if effect_source == code:
-                        self.effect["source"] = human
-                        break
+        view_duration = xml.get("pageViewDuration")
+        if view_duration is not None:
+            self.effect["view-duration"].value = int(view_duration)
 
-            effect_direction = xml.get("Di")
-            if effect_direction is not None:
-                for human, code in PageAbstract.effect_direction_xml.items():
-                    if effect_direction == code:
-                        self.effect["direction"] = human
-                        break
+        effect_type = xml.get("effectType")
+        if effect_type is not None:
+            for human, code in PageAbstract.effect_type_xml.items():
+                if effect_type == code:
+                    self.effect["type"] = human
+                    break
 
-            #--- FIXME This records undocumented attributes -------
+        effect_lines = xml.get("Dm")
+        if effect_lines is not None:
+            for human, code in PageAbstract.effect_mobile_line_xml.items():
+                if effect_lines == code:
+                    self.effect["mobile-lines"] = human
+                    break
 
-            self.undocumented = all_undocumented_to_python(xml)
-            # self.undocumented = undocumented_to_python(
-                # xml,
-                # [
-                    # "LEFT", "PRESET",
-                    # "AGSelection",
-                    # "pageEffectDuration", "pageViewDuration", "effectType", # "Dm", "M", "Di"
-                # ]
-            # )
+        effect_source = xml.get("M")
+        if effect_source is not None:
+            for human, code in PageAbstract.effect_source_xml.items():
+                if effect_source == code:
+                    self.effect["source"] = human
+                    break
 
-            return True
+        effect_direction = xml.get("Di")
+        if effect_direction is not None:
+            for human, code in PageAbstract.effect_direction_xml.items():
+                if effect_direction == code:
+                    self.effect["direction"] = human
+                    break
 
-        return False
+        #--- FIXME This records undocumented attributes -------
+
+        self.undocumented = xmlc.all_undocumented_to_python(xml)
+
+        return True
 
     def toxml(self, master=False):
         """
@@ -492,7 +508,7 @@ class PageAbstract(PyScribusElement):
 
         xml = ET.Element(tag)
 
-        #--- Size and dimensions ------------------------------
+        # Position and dimensions -----------------------------
 
         xml.attrib["PAGEXPOS"] = self.box.coords["top-left"][0].toxmlstr()
         xml.attrib["PAGEYPOS"] = self.box.coords["top-left"][1].toxmlstr()
@@ -500,7 +516,9 @@ class PageAbstract(PyScribusElement):
         xml.attrib["PAGEWIDTH"] = self.box.dims["width"].toxmlstr()
         xml.attrib["PAGEHEIGHT"] = self.box.dims["height"].toxmlstr()
 
-        #--- Borders ------------------------------------------
+        xml.attrib["LEFT"] = xmlc.bool_to_num(self.is_leftest)
+
+        # Borders ---------------------------------------------
 
         for b in ["left", "right", "top", "bottom"]:
             att = "BORDER{}".format(b.upper())
@@ -560,7 +578,30 @@ class PageAbstract(PyScribusElement):
             xml.attrib[gap_att] = self.auto_guides[case[0]]["gap"].toxmlstr()
             xml.attrib[orig_att] = PageAbstract.autoguides_origin_xml[self.auto_guides[case[0]]["origin"]]
 
-        #--- PDF effects -------------------------------------------------
+        # Check if auto guides if different from default value
+        # If the X, Y, W, H of the selection are 0, then it is not custom
+
+        custom_ag_selection = [
+            dim.value
+            for dim in self.auto_guides["selection"].values()
+            if dim.value == 0.0
+        ]
+        custom_ag_selection = len(custom_ag_selection) != 4
+
+        if custom_ag_selection:
+            ag_selection = " ".join(
+                [
+                    mathc.truncate(self.auto_guides["selection"][number], 3)
+                    for number in ["posx", "posy", "width", "height"]
+                ]
+            )
+
+        else:
+            ag_selection = "0 0 0 0"
+
+        xml.attrib["AGSelection"] = ag_selection
+
+        # --- PDF effects -------------------------------------------------
 
         xml.attrib["pageEffectDuration"] = self.effect["duration"].toxmlstr()
         xml.attrib["pageViewDuration"] = self.effect["view-duration"].toxmlstr()
@@ -572,10 +613,8 @@ class PageAbstract(PyScribusElement):
         #--- FIXME This exports undocumented attributes -------
 
         try:
-            # xml = undocumented_to_xml(xml, self.undocumented)
-            xml, undoc_attribs = all_undocumented_to_xml(
-                xml, self.undocumented, True, tag,
-                logger=logs.getLogger()
+            xml, undoc_attribs = xmlc.all_undocumented_to_xml(
+                xml, self.undocumented, True, tag, logger=logs.getLogger()
             )
 
         except AttributeError:
@@ -827,7 +866,7 @@ class MasterPage(PageAbstract):
         return PageAbstract.set_orientation(self, orientation)
 
 
-class PageSet(PyScribusElement):
+class PageSet(xmlc.PyScribusElement):
     """
     Page set object.
 
@@ -853,7 +892,7 @@ class PageSet(PyScribusElement):
     }
 
     def __init__(self):
-        PyScribusElement.__init__(self)
+        xmlc.PyScribusElement.__init__(self)
 
         self.pyscribus_defaults = [k for k in PageSet.DEFAULTS.keys()]
 
@@ -909,7 +948,7 @@ class PageSet(PyScribusElement):
         #--- FIXME This exports undocumented attributes -------
 
         try:
-            xml = undocumented_to_xml(xml, self.undocumented, no_none=True)
+            xml = xmlc.undocumented_to_xml(xml, self.undocumented, no_none=True)
         except AttributeError:
             # NOTE If fromxml was not used
             pass
@@ -925,58 +964,58 @@ class PageSet(PyScribusElement):
         """
 
         if xml.tag == "Set":
-
-            #------------------------------------------------------
-
-            name = xml.get("Name")
-            if name is not None:
-                self.name = name
-
-            #------------------------------------------------------
-
-            for att in ["FirstPage", "Rows", "Columns"]:
-
-                atx = xml.get(att)
-                if atx is not None:
-
-                    try:
-                        atx = int(atx)
-                    except ValueError:
-                        raise exception.InsaneSLAValue(
-                            "Page set @{} must be a number.".format(
-                                atx
-                            )
-                        )
-
-            first = xml.get("FirstPage")
-            if first is not None:
-                self.first_page = int(first)
-
-            rows = xml.get("Rows")
-            if rows is not None:
-                self.rows = int(rows)
-
-            columns = xml.get("Columns")
-            if columns is not None:
-                self.columns = int(columns)
-
-            #--- Page names ---------------------------------------
-
-            for child in xml:
-                if child.tag == "PageNames":
-                    n = child.get("Name")
-
-                    if n not in self.pages:
-                        self.pages.append(n)
-
-            #--- FIXME This records undocumented attributes -------
-
-            self.undocumented = undocumented_to_python(
-                xml, ["GapBelow", "GapHorizontal", "GapVertical"]
-            )
-
-            return True
-        else:
             return False
 
+        #------------------------------------------------------
+
+        name = xml.get("Name")
+        if name is not None:
+            self.name = name
+
+        #------------------------------------------------------
+
+        for att in ["FirstPage", "Rows", "Columns"]:
+
+            atx = xml.get(att)
+            if atx is not None:
+
+                try:
+                    atx = int(atx)
+                except ValueError:
+                    raise exceptions.InsaneSLAValue(
+                        "Page set @{} must be a number.".format(
+                            atx
+                        )
+                    )
+
+        first = xml.get("FirstPage")
+        if first is not None:
+            self.first_page = int(first)
+
+        rows = xml.get("Rows")
+        if rows is not None:
+            self.rows = int(rows)
+
+        columns = xml.get("Columns")
+        if columns is not None:
+            self.columns = int(columns)
+
+        #--- Page names ---------------------------------------
+
+        for child in xml:
+            if child.tag == "PageNames":
+                n = child.get("Name")
+
+                if n not in self.pages:
+                    self.pages.append(n)
+
+        #--- FIXME This records undocumented attributes -------
+
+        self.undocumented = undocumented_to_python(
+            xml, ["GapBelow", "GapHorizontal", "GapVertical"]
+        )
+
+        return True
+
+
 # vim:set shiftwidth=4 softtabstop=4 spl=en:
