@@ -369,13 +369,13 @@ class LPI(PyScribusElement):
         self.pyscribus_defaults = [l[0] for l in LPI.DEFAULTS]
 
         # Linescreening angle
-        self.angle = dimensions.Dim(0, "deg")
+        self.angle = dimensions.Dim(0, unit="deg")
 
         # Name of the Colour for which these settings are ment
         self.color = ""
 
         # How many lines per Inch are used
-        self.frequency = dimensions.Dim(133, "lpi")
+        self.frequency = dimensions.Dim(133, unit="lpi", integer=True)
 
         # Code for the used Spotfunction
         self.spot = "ellipse"
